<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:crane="http://www.CraneSoftwrights.com/ns/site"
                exclude-result-prefixes="crane"
                version="1.0">

<!-- $Id: cranecal.xsl,v 1.17 2008/11/18 02:11:08 gkholman Exp $ -->

<!-- This stylesheet is meant to be imported into another stylesheet for
     access and display of Crane's calendar of training courses.

     Just import this and call the template:

        {http://www.CraneSoftwrights.com/ns/misc}calendar

     An example shell stylesheet is found in the ZIP package pointed to at:

        http://www.CraneSoftwrights.com/training/cranecal.htm

     The package as delivered uses a local filename reference for finding
     the XML file; this must be changed by changing the parameter names
     to point to the remote filename reference.
-->

<xsl:template match="/crane">
  <xsl:call-template name="crane:calendar">
    <xsl:with-param name="crane" select="."/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="crane:calendar">
  <xsl:param name="calendar-remote"
    select="'http://www.CraneSoftwrights.com/training/crane-courses.xml'"/>
  <xsl:param name="calendar"
    select="'crane-courses.xml'"/>
  <xsl:param name="crane" select="document($calendar)/crane"/>

  <xsl:variable name="courses" select="$crane/course"/>

  <xsl:if test="not($crane)">
    <xsl:message terminate="yes">
      <xsl:text>Change the declaration for the $calendar parameter </xsl:text>
      <xsl:text>to find the required file.</xsl:text>
    </xsl:message>
  </xsl:if>

  <table summary="Summary of Crane's instructor-led training deliveries"
         border="1" width="100%">
    <tr>
      <td align="center"><b>Courses</b>
      <small> (<xsl:value-of select="$crane/@date"/>)</small>
      </td>
      <td align="center"><b>Locations</b></td>
      <td align="center"><b>Lengths</b></td>
      <td align="center"><b>Dates</b></td>
    </tr>
    <xsl:for-each select="$courses">
      <xsl:sort select="title"/>
      <tr>
        <td valign="center" rowspan="{count(deliveries/delivery)}">
          <a href="{$crane/@upcoming}#{@id}" target="_blank">
            <xsl:value-of select="title"/>
          </a>
          <small>
            <xsl:text> </xsl:text>
            <a href="{@syllabus}" style="white-space:nowrap"
              target="_blank">(syllabus)</a>
            <xsl:text> </xsl:text>
            <a href="{$crane/@past}#{@id}" style="white-space:nowrap"
               target="_blank">(past deliveries)</a>
          </small>
        </td>
        <xsl:choose>
          <xsl:when test="deliveries/delivery">
            <xsl:for-each select="deliveries/delivery[1]">
              <xsl:call-template name="crane:delivery"/>
            </xsl:for-each>
          </xsl:when>
          <xsl:otherwise>
            <td colspan="3" align="center">
              <xsl:text>(none scheduled at this time)</xsl:text>
            </td>
          </xsl:otherwise>
        </xsl:choose>
      </tr>
      <xsl:if test="deliveries/delivery[2]">
        <xsl:for-each select="deliveries/delivery[position()>1]">
          <tr>
            <xsl:call-template name="crane:delivery"/>
          </tr>
        </xsl:for-each>
      </xsl:if>
    </xsl:for-each>
  </table>
</xsl:template>

<xsl:template name="crane:delivery">
  <td>
    <xsl:value-of select="location"/>
    <xsl:if test="@info">
      <xsl:text> </xsl:text>
      <small>
        <a href="{@info}" target="_blank">(info)</a>
      </small>
    </xsl:if>
    <xsl:if test="@pricing">
      <xsl:text> </xsl:text>
      <small>
        <a href="{@pricing}" target="_blank">(pricing)</a>
      </small>
    </xsl:if>
    <xsl:if test="@host">
      <xsl:text> </xsl:text>
      <small>
        <a href="{@host}" target="_blank">(host)</a>
      </small>
    </xsl:if>
    <xsl:if test="@registration">
      <xsl:text> </xsl:text>
      <small>
        <a href="../{@registration}" target="_blank">(registration)</a>
      </small>
    </xsl:if>
  </td>
  <td><xsl:value-of select="length"/></td>
  <td>
    <span style="white-space:nowrap">
      <xsl:value-of select="@date"/>
    </span>
  </td>
</xsl:template>

</xsl:stylesheet>
